Worker Resources Module
=======================
.. automodule:: resources.worker_resources
..   :members: Resources

.. autoclass:: ResourceManager
  :show-inheritance:
  :member-order: bysource
  :members:

  .. automethod:: __init__

.. autoclass:: WorkerResources
  :show-inheritance:
  :member-order: bysource
  :members:

  .. automethod:: __init__
